abacusai.video_search_result — AbacusAI documentation

# abacusai.video_search_result

## Classes

`VideoSearchResult` | A single video search result.

## Module Contents

class abacusai.video_search_result.VideoSearchResult(client, title=None, url=None, thumbnailUrl=None, motionThumbnailUrl=None, embedUrl=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A single video search result.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - title (str) – The title of the video.

    - url (str) – The URL of the video.

    - thumbnailUrl (str) – The URL of the thumbnail of the video.

    - motionThumbnailUrl (str) – The URL of the motion thumbnail of the video.

    - embedUrl (str) – The URL of the embed of the video.

  title
  url
  thumbnail_url
  motion_thumbnail_url
  embed_url
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict